wfc_pub library

Properties

logger ↔ Logger
wfc_pub.dart this is an application that uses the Wave Function collapse it iterates through the examples in the assets/samples creating maps from the configurations found there
getter/setter pair

Functions

main() → void
parseTilesFromFile(String filePath) Future<List<Tile>>
prepareOutputDestination(String pathToOutput) → void